@@ -1,7 +1,7 @@
-from . import (applications, callbacks, datasets, functions, layers, utils)
+from . import applications, callbacks, datasets, functions, layers, utils
 from .modules import constraints, initializers, losses, metrics, regularizers
 
-__version__ = '0.2.1'
+__version__ = '0.3.0'
 
 __all__ = [
     'applications',
